package com.persagy.dmp.rwd.digital.controller;

import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.dmp.basic.model.QueryCriteria;
import com.persagy.dmp.basic.utils.QueryCriteriaHelper;
import com.persagy.dmp.common.constant.CommonConstant;
import com.persagy.dmp.common.constant.ResponseCode;
import com.persagy.dmp.common.exception.BusinessException;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.common.utils.ParamCheckUtil;
import com.persagy.dmp.common.utils.ResultHelper;
import com.persagy.dmp.mybatis.utils.ConditionUtil;
import com.persagy.dmp.rwd.digital.entity.ObjectRelation;
import com.persagy.dmp.rwd.digital.service.IObjectRelationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;

/**
 * 关系数据 Controller
 * @author Charlie Yu
 * @date 2021-07-08
 */
@RestController
@RequestMapping("/rwd/instance/relation")
public class ObjectRelationController {

    @Autowired
    private IObjectRelationService service;

    @PostMapping("query")
    public CommonResult<List<ObjectRelation>> query(@RequestBody QueryCriteria criteria) {
        if(criteria == null) {
            throw new BusinessException(ResponseCode.A0400.getCode(), ResponseCode.A0400.getDesc());
        }
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE,CommonConstant.QUERY_PROJECTID);

        QueryWrapper<ObjectRelation> wrapper = new QueryWrapper<>();
        // 添加所属项目条件
        ConditionUtil.ensureProjectCriteria(wrapper);
        // 转换查询条件
        QueryCriteriaHelper.toWrapper(wrapper, criteria);
        Page page = service.queryByCondition(QueryCriteriaHelper.toPage(criteria), wrapper);
        return ResultHelper.multi(page.getRecords(), page.getTotal());
    }

    @PostMapping("/createOne")
    public CommonResult<ObjectRelation> create(@Valid @RequestBody ObjectRelation vo){
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE,CommonConstant.QUERY_PROJECTID);

        List<ObjectRelation> voList = CollUtil.newArrayList(vo);
        service.insert(voList);
        return ResultHelper.single(vo);
    }

    @PostMapping("/create")
    public CommonResult<List<ObjectRelation>> createBatch(@Valid @RequestBody List<ObjectRelation> voList){
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE,CommonConstant.QUERY_PROJECTID);

        voList = service.insert(voList);
        return ResultHelper.multi(voList);
    }

    @PostMapping("/updateOne")
    public CommonResult<ObjectRelation> update(@Valid @RequestBody ObjectRelation vo){
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE,CommonConstant.QUERY_PROJECTID);

        List<ObjectRelation> voList = CollUtil.newArrayList(vo);
        service.update(voList);
        return ResultHelper.single(vo);
    }

    @PostMapping("/update")
    public CommonResult<List<ObjectRelation>> updateBatch(@Valid @RequestBody List<ObjectRelation> voList){
        //基础参数校验
        ParamCheckUtil.checkParam(CommonConstant.QUERY_GROUPCODE,CommonConstant.QUERY_PROJECTID);

        voList = service.update(voList);
        return ResultHelper.multi(voList);
    }

    @PostMapping("/deleteOne")
    public CommonResult delete(@RequestBody String id){
        service.delete(CollUtil.newArrayList(id));
        return ResultHelper.success();
    }

    @PostMapping("/delete")
    public CommonResult deleteBatch(@RequestBody List<String> id){
        service.delete(id);
        return ResultHelper.success();
    }
}
